import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Input, Select, Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {DescItem} from "@/components/Description";
import {uploadApi} from "@/api/sys/upload"; // 引入开关组件
type CheckedType = boolean | string | number;

/**主页面列表 表头*/
export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'apiName',
    width: 150,
    slots: { customRender: 'apiName' },
  },
  {
    title: '权属工作组',
    dataIndex: 'workGroup',
    width: 150,
  },
  {
    title: '模式',
    dataIndex: 'mode',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
/**主页面搜索 表单*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'apiName',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 6 },
  },
];
/**新建API 表单*/
export const createAPIFormSchema: FormSchema[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'documentName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
  },
  {
    field: 'documentType',
    label: '文件类型',
    component: 'Input',
    defaultValue: 'API',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入文件类型',
    },
  },
  {
    field: 'catalogOwnershipMode',
    label: '目录权属模式',
    component: 'Input',
    defaultValue: '本级定义',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入目录权属模式',
    },
  },
  {
    field: 'workGroup',
    label: '权属工作组',
    component: 'Input',
    defaultValue: '默认工作组',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      style: { border: 'none' },
      readonly: true,
      placeholder: '请输入权属工作组',
    },
  },
];
/**新建文件夹 表单*/
export const createDocumentFormSchema: FormSchema[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'documentName',
    label: '文件夹名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件夹名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件夹名称',
    },
  },
];
/**导入 表单*/
export const importApiFormSchema: FormSchema[] = [
  {
    field: 'importType',
    component: 'RadioGroup',
    label: '导入类型',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'1',
      options: [
        {
          label: '同集群导入',
          value: '1',
        },
        {
          label: '其他集群导入',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'path',
    label: '导入至',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'file',
    component: 'Upload',
    label: '导入文件选择',
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '文件重名',
    colProps: { lg: 24, md: 24 },
    labelWidth: 150,
    componentProps: {
      defaultValue:'3',
      options: [
        {
          label: '全部放弃',
          value: '1',
        },
        {
          label: '全部替换',
          value: '2',
        },
        {
          label: '自动重命名',
          value: '3',
        },
      ],
    },
  },
];
/**移动 表单*/
export const moveFormSchema: any[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**复制 表单*/
export const copyFormSchema: any[] = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'apiName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]
/**重命名 表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'apiName',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**apiDoc列表 表头*/
export const apiDocColumns: BasicColumn[] = [
 {
    "title": "参数code",
    "dataIndex": "parameterCode",
    "width": 120
  },
  {
    "title": "参数位置",
    "dataIndex": "parameterPosition",
    "width": 120
  },
  {
    "title": "Xpath",
    "dataIndex": "xpath",
    "width": 120
  },
  {
    "title": "参数类型",
    "dataIndex": "parameterType",
    "width": 120
  },
  {
    "title": "注释",
    "dataIndex": "annotation",
    "width": 120
  },
  {
    "title": "是否必填",
    "dataIndex": "isRequired",
    "width": 120
  },
  {
    "title": "参数值",
    "dataIndex": "parameterValue",
    "width": 120,
    "editable": true,
    "edit": true
  }
];
/**版本发布申请 表单*/
export const publishApplicationFormSchema: any[] = [
   {
    "field": "applicationTitle",
    "label": "申请标题",
    "component": "Input",
    "colProps": { "lg": 24, "md": 24 },
    "rules": [
      {
        "required": true,
        "message": "请输入申请标题"
      }
    ],
    "componentProps": {
      "placeholder": "请输入申请标题"
    }
  },
  {
    "field": "applicationReason",
    "label": "申请理由",
    "component": "InputTextArea",
    "colProps": { "lg": 24, "md": 24 },
    "rules": [
      {
        "required": true,
        "message": "请输入申请理由"
      }
    ],
    "componentProps": {
      rows: 4,
      "placeholder": "请输入申请理由"
    }
  },
  {
    "field": "versionDescription",
    "label": "版本说明",
     "component": "InputTextArea",
    "colProps": { "lg": 24, "md": 24 },
    "rules": [
      {
        "required": true,
        "message": "请输入版本说明"
      }
    ],
    "componentProps": {
      rows: 4,
      "placeholder": "请输入版本说明"
    }
  },
  {
    "field": "apiName",
    "label": "API名称",
    "component": "Input",
    "colProps": { "lg": 24, "md": 24 },
    "rules": [
      {
        "required": true,
        "message": "请输入API名称"
      }
    ],
    "componentProps": {
      disabled: true,
      "placeholder": "请输入API名称"
    }
  }
]
/**向导模式 表单1*/
export const guideModeFormSchema: FormSchema[] = [
  {
    field: "dataSource",
    label: "数据源",
    component: "Select",
    colProps: { span: 5 },
    rules: [
      {
        required: true,
        message: "请选择数据源"
      }
    ],
    defaultValue: 'mysql',
    componentProps: {
      options: [
        {
          label: "inceptor",
          value: "inceptor",
        },
        {
          label: "argodb",
          value: "argodb",
        },
        {
          label: "kundb",
          value: "kundb",
        },
        {
          label: "mysql",
          value: "mysql",
        },
        {
          label: "oracle",
          value: "oracle",
        },
        {
          label: "db2",
          value: "db2",
        },
        {
          label: "DM",
          value: "DM",
        },
        {
          label: "Hana",
          value: "Hana",
        },
        {
          label: "PostgreSql",
          value: "PostgreSql",
        },
      ],
      placeholder: "请选择数据源"
    }
  },
  {
    "field": "database",
    "label": "数据库",
    "component": "Select",
    colProps: { span: 5 },
    "rules": [
      {
        "required": true,
        "message": "请选择数据库"
      }
    ],
    defaultValue: '1',
    "componentProps": {
      options: [
        {
          label: '_demo0412',
          value: '1'
        },
        {
          label: 'dataBase2',
          value: '2'
        },
        {
          label: 'dataBase3',
          value: '3'
        },
        {
          label: 'dataBase4',
          value: '4 '
        },
      ],
      "placeholder": "请选择数据库"
    }
  },
  {
    "field": "dataTable",
    "label": "数据表",
    "component": "Select",
    colProps: { span: 5 },
    "rules": [
      {
        "required": true,
        "message": "请选择数据表"
      }
    ],
    defaultValue: '1',
    "componentProps": {
      options: [
        {
          label: '_demo0412',
          value: '1'
        },
        {
          label: 'dataTable2',
          value: '2'
        },
        {
          label: 'dataTable3',
          value: '3'
        },
        {
          label: 'dataTable4',
          value: '4 '
        },
      ],
      "placeholder": "请选择数据表"
    }
  }
];
/**向导模式 表单2*/
export const guideModeFormSchema2: FormSchema[] = [
  {
    field: 'apiName',
    label: 'API名称',
    component: 'Input',
    defaultValue: 'API_ONE',
    rules: [
      {
        required: true,
        message: '请输入API名称',
      },
    ],
  },
  {
    field: 'apiDescription',
    label: 'API描述',
    component: 'InputTextArea',
    componentProps: {
      placeholder: '请输入API描述',
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'timeOut',
    label: '超时时间',
    component: 'Input',
    defaultValue: '5',
    rules: [
      {
        required: true,
        message: '请输入超时时间',
      },
    ],
    suffix: '秒',
  },
  {
    field: 'label',
    label: 'Label',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择Label',
      },
    ],
    defaultValue: '1',
    componentProps: {
      mode: 'multiple',
      options:[
        {
          label:'用户',
          value:'1'
        },
        {
          label:'查询',
          value:'2'
        },
      ],
      placeholder: '请选择Label',
    },
  },
  {
    field: 'type',
    label: '类别',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择类别',
      },
    ],
    defaultValue: '1',
    componentProps: {
      options:[
        {
          label:'API类别1',
          value:'1'
        },
        {
          label:'API类别2',
          value:'2'
        },
        {
          label:'API类别3',
          value:'3'
        },
      ],
      placeholder: '请选择类别',
    },
  },
];
/**向导模式 列表1*/
export const guideModeTableColumns1: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'column',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'id',
          value: '1',
        },
        {
          label: '列名2',
          value: '2',
        },
      ],
    },
    width: 200,
  },
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 200,
    edit: true,
    editable: true,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 200,
    edit: true,
    editable: true,
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    edit: true,
    editable: true,
    editComponent: 'Checkbox',
    editValueMap: (value) => {
      return value ? '是' : '否';
    },
    width: 200,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150
  },
  {
    title: '示例值',
    dataIndex: 'exampleValue',
    width: 200,
    edit: true,
    editable: true,
  },
];
/**向导模式 列表2*/
export const guideModeTableColumns2: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'column',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'id',
          value: '1',
        },
        {
          label: '列名2',
          value: '2',
        },
      ],
    },
    width: 200,
  },
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 200,
    edit: true,
    editable: true,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '参数映射字段',
    dataIndex: 'parameterMappingFields',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '用户ID',
          value: '1',
        },
        {
          label: '列名2',
          value: '2',
        },
      ],
    },
    width: 200,
  },
];
/**向导模式 列表3*/
export const guideModeTableColumns3: BasicColumn[] = [
 {
    title: '列名',
    dataIndex: 'column',
    edit: true,
    editable: true,
    width: 200,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'midgard_offset',
          value: '1',
        },
        {
          label: 'midgard_size',
          value: '2',
        },
      ],
    },
  },
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 200,
    edit: true,
    editable: true,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    edit: true,
    editable: true,
    editComponent: 'Checkbox',
    editValueMap: (value) => {
      return value ? '是' : '否';
    },
    width: 200,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150,
    edit: true,
    editable: true,
  },
];
/**向导模式 列表4*/
export const guideModeTableColumns4: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'column',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'age',
          value: '1',
        },
        {
          label: 'address',
          value: '2',
        },
        {
          label: 'create_time',
          value: '3',
        },
      ],
    },
    width: 200,
  },
 {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 200,
    edit: true,
    editable: true,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '示例值',
    dataIndex: 'exampleValue',
    width: 150,
    edit: true,
    editable: true,
  },
];
/**向导模式 列表5*/
export const guideModeTableColumns5: BasicColumn[] = [
 {
    title: '列名',
    dataIndex: 'column',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'age',
          value: '1',
        },
        {
          label: 'id',
          value: '2',
        },
      ],
    },
    width: 200,
  },
  {
    title: '排序方式',
    dataIndex: 'orderType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '升序',
          value: '1',
        },
        {
          label: '降序',
          value: '2',
        },
      ],
    },
    width: 200,
  },
];
/**向导模式 列表6*/
export const guideModeTableColumns6: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'column',
    width: 150
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150
  },
];
/**向导模式 列表7*/
export const guideModeTableColumns7: BasicColumn[] = [
  {
    title: '参数1',
    dataIndex: 'param1',
    width: 100
  },
  {
    title: '参数2',
    dataIndex: 'param2',
    width: 100
  },
  {
    title: '参数3',
    dataIndex: 'param3',
    width: 100
  },
   {
    title: '参数4',
    dataIndex: 'param4',
    width: 100
  },
   {
    title: '参数5',
    dataIndex: 'param5',
    width: 80
  },
   {
    title: '参数6',
    dataIndex: 'param6',
    width: 80
  },
  {
    title: '参数7',
    dataIndex: 'param7',
    width: 150,
    editable: true,
    edit:true
  },
];
/**向导模式 列表8*/
export const guideModeTableColumns8: BasicColumn[] = [
  {
    title: 'value',
    dataIndex: 'value',
    width: 100
  },
];
/**类别管理-新增 表单*/
export const addTypeFormSchema: FormSchema[] = [
  {
    field: 'typeName',
    label: '类别名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入类别名称',
      },
    ],
    componentProps: {
      placeholder: '请输入类别名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**类别管理-列表 表头*/
export const typeManageTableColumn: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'typeName',
    width: 150,
  },
];
/**版本管理列表 表头*/
export const versionColumns: BasicColumn[] = [
  {
    title: '版本号',
    dataIndex: 'versionId',
    width: 150,
  },
  {
    title: '修改人',
    dataIndex: 'submitBy',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'submitDate',
    width: 150,
  },
];
/**版本管理弹出框 搜索表头*/
export const versionSearchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '请输入类别名称',
    },
    colProps: { span: 7 },
  },
];
/**SQL模式-步骤1 列表表头1*/
export const step1TableColumns1: BasicColumn[] = [
 {
    "title": '参数',
    "dataIndex": 'parameter',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    "title": '别名',
    "dataIndex": 'alias',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    title: '来源SQL',
    dataIndex: 'sourceSql',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'S1',
          value: '1',
        },
        {
          label: 'S2',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    "title": '',
    "dataIndex": 'sql',
    "width": 150,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'Int',
          value: '1',
        },
        {
          label: 'String',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    "title": '注释',
    "dataIndex": 'comment',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    "title": '默认值',
    "dataIndex": 'defaultValue',
    "width": 150,
    edit: true,
    editable: true,
  }
];
/**SQL模式-步骤1 列表表头2*/
export const step1TableColumns2: BasicColumn[] = [
 {
    "title": '参数',
    "dataIndex": 'parameter',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    "title": '别名',
    "dataIndex": 'alias',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    title: '来源SQL',
    dataIndex: 'sourceSql',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'S1',
          value: '1',
        },
        {
          label: 'S2',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    "title": '',
    "dataIndex": 'sql',
    "width": 150,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'Int',
          value: '1',
        },
        {
          label: 'String',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '参数映射字段',
    dataIndex: 'parameterMappingFields',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '用户ID',
          value: '1',
        },
      ],
    },
    width: 150,
  },
];
/**SQL模式-步骤1 列表表头3*/
export const step1TableColumns3: BasicColumn[] = [
 {
    "title": '列名',
    "dataIndex": 'column',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    "title": '别名',
    "dataIndex": 'alias',
    "width": 150,
    edit: true,
    editable: true,
  },
  {
    title: '来源SQL',
    dataIndex: 'sourceSql',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'S1',
          value: '1',
        },
        {
          label: 'S2',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    "title": '',
    "dataIndex": 'sql',
    "width": 150,
  },
  {
    "title": '注释',
    "dataIndex": 'comment',
    "width": 150,
    edit: true,
    editable: true,
  },
];
/**SQL模式-步骤1 列表表头4*/
export const step1TableColumns4: BasicColumn[] = [
 {
    title: 'SQL',
    dataIndex: 'sql',
    width: 150,
  },
  {
    title: '别名',
    dataIndex: 'alias',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: 'SQL类型',
    dataIndex: 'sqlType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '查询类SQL',
          value: '1',
        },
        {
          label: '添加类SQL',
          value: '2',
        },
        {
          label: '修改类SQL',
          value: '3',
        },
        {
          label: '删除类SQL',
          value: '4',
        },
      ],
    },
    width: 150,
  },
  {
    title: '最大返回记录数',
    dataIndex: 'returnRecordCount',
    width: 150,
    edit: true,
    editable: true,
  },
];
/**SQL模式-步骤2 列表表头1*/
export const step2TableColumns1: BasicColumn[] = [
    {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'Body',
          value: '1',
        },
        {
          label: 'Path',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'number',
          value: '1',
        },
        {
          label: 'array',
          value: '2',
        },
        {
          label: 'object',
          value: '3',
        },
        {
          label: 'string',
          value: '4',
        },
      ],
    },
    width: 150,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '是否必填',
    dataIndex: 'isNeed',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '是',
          value: '1',
        },
        {
          label: '否',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '示例值',
    dataIndex: 'exampleValue',
    width: 150,
    edit: true,
    editable: true,
  }
];
/**SQL模式-步骤2 列表表头1*/
export const step2TableColumns2: BasicColumn[] = [
   {
    title: '原始入参',
    dataIndex: 'originalInput',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '映射类型',
    dataIndex: 'mappingType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '开放入参',
          value: '1',
        },
        {
          label: '映射表达式',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '开放入参/映射表达式',
    dataIndex: 'mappingExpression',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'size',
          value: '1',
        },
        {
          label: 'sortRules',
          value: '2',
        },
        {
          label: 'category',
          value: '3',
        },
        {
          label: 'filterRules',
          value: '4',
        },
        {
          label: 'page',
          value: '5',
        },
        {
          label: 'childrenRequest',
          value: '6',
        },
      ],
    },
    width: 150,
  },
];
/**SQL模式-步骤3 列表表头1*/
export const step3TableColumns1: BasicColumn[] = [
    {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'Body',
          value: '1',
        },
        {
          label: 'Path',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'number',
          value: '1',
        },
        {
          label: 'array',
          value: '2',
        },
        {
          label: 'object',
          value: '3',
        },
        {
          label: 'string',
          value: '4',
        },
      ],
    },
    width: 150,
  },
];
/**SQL模式-步骤3 列表表头2*/
export const step3TableColumns2: BasicColumn[] = [
   {
    title: '开放出参',
    dataIndex: 'originalOutput',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '映射类型',
    dataIndex: 'mappingType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '原始出参',
          value: '1',
        },
        {
          label: '返回结果码',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '映射对象',
    dataIndex: 'mappingObject',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'S1.size',
          value: '1',
        },
        {
          label: 'S1.sortRules',
          value: '2',
        },
        {
          label: 'S1.category',
          value: '3',
        },
        {
          label: 'S1.filterRules',
          value: '4',
        },
        {
          label: 'S1.page',
          value: '5',
        },
        {
          label: 'S1.childrenRequest',
          value: '6',
        },
      ],
    },
    width: 150,
  },
];
/**托管模式- 列表表头1*/
export const trusteeshipTableColumns1: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'QUERY',
          value: '1',
        },
        {
          label: 'BODY',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'number',
          value: '1',
        },
        {
          label: 'array',
          value: '2',
        },
        {
          label: 'object',
          value: '3',
        },
        {
          label: 'string',
          value: '4',
        },
      ],
    },
    width: 150,
  },
];
/**托管模式- 列表表头2*/
export const trusteeshipTableColumns2: BasicColumn[] = [
    {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'Body',
          value: '1',
        },
        {
          label: 'Path',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'number',
          value: '1',
        },
        {
          label: 'array',
          value: '2',
        },
        {
          label: 'object',
          value: '3',
        },
        {
          label: 'string',
          value: '4',
        },
      ],
    },
    width: 150,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '是否必填',
    dataIndex: 'isNeed',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '是',
          value: '1',
        },
        {
          label: '否',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '示例值',
    dataIndex: 'exampleValue',
    width: 150,
    edit: true,
    editable: true,
  }
];
/**托管模式- 列表表头3*/
export const trusteeshipTableColumns3: BasicColumn[] = [
   {
    title: '原始入参',
    dataIndex: 'originalInput',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '映射类型',
    dataIndex: 'mappingType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '开放入参',
          value: '1',
        },
        {
          label: '映射表达式',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '开放入参/映射表达式',
    dataIndex: 'mappingExpression',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'size',
          value: '1',
        },
        {
          label: 'sortRules',
          value: '2',
        },
        {
          label: 'category',
          value: '3',
        },
        {
          label: 'filterRules',
          value: '4',
        },
        {
          label: 'page',
          value: '5',
        },
        {
          label: 'childrenRequest',
          value: '6',
        },
      ],
    },
    width: 150,
  },
];
/**托管模式- 列表表头4*/
export const trusteeshipTableColumns4: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    width: 150,
  },
  {
    title: '参数值',
    dataIndex: 'parameterValue',
    width: 150,
    edit: true,
    editable: true,
  },
];
/**托管模式- 列表表头5*/
export const trusteeshipTableColumns5: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'QUERY',
          value: '1',
        },
        {
          label: 'BODY',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'number',
          value: '1',
        },
        {
          label: 'array',
          value: '2',
        },
        {
          label: 'object',
          value: '3',
        },
        {
          label: 'string',
          value: '4',
        },
      ],
    },
    width: 150,
  },
];
/**托管模式- 列表表头6*/
export const trusteeshipTableColumns6: BasicColumn[] = [
   {
    title: '开放出参',
    dataIndex: 'originalInput',
    width: 150,
    edit: true,
    editable: true,
  },
  {
    title: '映射类型',
    dataIndex: 'mappingType',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '原始出参',
          value: '1',
        },
        {
          label: '映射表达式',
          value: '2',
        },
      ],
    },
    width: 150,
  },
  {
    title: '原始出参/映射表达式',
    dataIndex: 'mappingExpression',
    edit: true,
    editable: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'size',
          value: '1',
        },
        {
          label: 'sortRules',
          value: '2',
        },
        {
          label: 'category',
          value: '3',
        },
        {
          label: 'filterRules',
          value: '4',
        },
        {
          label: 'page',
          value: '5',
        },
        {
          label: 'childrenRequest',
          value: '6',
        },
      ],
    },
    width: 150,
  },
];
/**托管模式- 列表表头7*/
export const trusteeshipTableColumns7: BasicColumn[] = [
    {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150,
  },
  {
    title: '参数位置',
    dataIndex: 'parameterLocation',
    width: 150,
  },
  {
    title: 'Xpath',
    dataIndex: 'Xpath',
    width: 150,
  },
  {
    title: '数据类型',
    dataIndex: 'dataType',
    width: 150,
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150,
  },
  {
    title: '是否必填',
    dataIndex: 'isNeed',
    width: 150,
  },
  {
    title: '参数值',
    dataIndex: 'parameterValue',
    width: 150,
    edit: true,
    editable: true,
  },
];
/**托管模式- 表单1*/
export const trusteeshipFormSchema1: FormSchema[] = [
  {
    field: '',
    label: '源服务配置',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'protocolType',
    label: '协议类型',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options:[
        {
          label:'http',
          value:'1'
        },
        {
          label:'https',
          value:'2'
        }
      ],
      placeholder: '请选择协议类型',
    },
    rules: [
      {
        required: true,
        message: '请选择协议类型',
      },
    ],
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'method',
    label: 'method',
    component: 'Select',
    defaultValue: '2',
    componentProps: {
      options:[
        {
          label:'Get',
          value:'1'
        },
        {
          label:'Post',
          value:'2'
        },
        {
          label:'Put',
          value:'3'
        },
        {
          label:'Delete',
          value:'4'
        },
        {
          label:'Options',
          value:'5'
        },
        {
          label:'Trace',
          value:'6'
        },
        {
          label:'Patch',
          value:'7'
        }
      ],
      placeholder: '请选择method',
    },
    rules: [
      {
        required: true,
        message: '请选择method',
      },
    ],
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'url',
    label: 'URL',
    component: 'Input',
    defaultValue: 'http://api.tds.transwarp.io/tds/midgard/test/11/',
    componentProps: {
      placeholder: '请输入URL',
    },
    rules: [
      {
        required: true,
        message: '请输入URL',
      },
    ],
    colProps: { lg: 24, md: 24 },
  },
];
/**托管模式- 表单2*/
export const trusteeshipFormSchema2: FormSchema[] = [
  {
    field: '',
    label: '请求代码',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'header1',
    label: 'header:',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        requirer: true,
        message: '请输入申请理由'
      }
    ],
    defaultValue:'Accept: application/json, text/plain, */*\n' +
        'Accept-Encoding: gzip, deflate\n' +
        'Accept-Language: zh-CN,zh;q=0.9,en;q=0.8\n'+
        'Authorization:\n'+
        'Content-Length: 218\n' +
        'Content-Type: application/json;charset=UTF-8\n' +
        'Host: 172.26.2.22:28180\n' +
        'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36\n' +
        'x-requested-with: XMLHttpRequest',
    componentProps: {
      readonly: true,
      rows: 10,
      placeholder: '请输入申请理由'
    }
  },
  {
    field: "body1",
    label: "body:",
    component: "InputTextArea",
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    defaultValue: '{\n'+
              '"category": "SERVICE",\n'+
              '"page": 1,\n'+
              '"size": 10,\n'+
              '"searchText": "",\n'+
              '"size": 10,\n'+
              '"timeRangeFilters": [],\n'+
              '"fieldFuzzySearch": [],\n'+
              '"childrenRequest": null,\n'+
              '"catalogFlag": false\n'+
             '}',
    componentProps: {
      readonly: true,
      rows: 10,
      placeholder: "请输入申请理由"
    }
  },
  {
    field: '',
    label: '返回结果源码',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: "header2",
    label: "header:",
    component: "InputTextArea",
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    defaultValue: 'Cache-Control: no-cache, no-store, max-age=0, must-revalidate\n' +
        'Content-Type: application/json\n' +
        'Date: Wed, 01 Feb 2023 08:51:06 GMT\n'+
        'Expires: Thu, 01 Feb 2023 08:51:06 GMT\n'+
        'Pragma: 0\n'+
        'Referrer-Policy: no-referrer\n' +
        'Transfer-Encoding: chunked\n' +
        'X-Content-Type-Options: nosniff\n' +
        'X-Frame-Options: DENY\n' +
        'X-XSS-Protection: 1; mode=block',
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入申请理由"
    }
  },
  {
    field: "body2",
    label: "body:",
    component: "InputTextArea",
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    defaultValue:'{\n'+
              '"category": "SERVICE",\n'+
              '"page": 1,\n'+
              '"size": 10,\n'+
              '"searchText": "",\n'+
              '"size": 10,\n'+
              '"timeRangeFilters": [],\n'+
              '"fieldFuzzySearch": [],\n'+
              '"childrenRequest": null,\n'+
              '"catalogFlag": false\n'+
             '}',
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入申请理由"
    }
  },
];
/**托管模式- 表单3*/
export const trusteeshipFormSchema3: FormSchema[] = [
  {
    field: '',
    label: '请求URL',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'testUrl',
    label: '测试URL',
    component: 'Input',
    defaultValue: 'http://172.26.2.22/${code1}/test/${code2}',
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入URL',
    },
    rules: [
      {
        required: true,
        message: '请输入URL',
      },
    ],
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'requestUrl',
    label: '请求URL',
    component: 'Input',
    componentProps: {
      placeholder: '请输入URL',
    },
    rules: [
      {
        required: true,
        message: '请输入URL',
      },
    ],
    itemProps: {
      extra: '请复制测试URL并按API配置修改其中的参数信息',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: '',
    label: '请求代码',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: "header",
    label: "header:",
    component: "InputTextArea",
    defaultValue: 'Accept: application/json, text/plain, */*\n' +
        'Accept-Encoding: gzip, deflate\n' +
        'Accept-Language: zh-CN,zh;q=0.9,en;q=0.8\n'+
        'Authorization:\n'+
        'Content-Length: 218\n' +
        'Content-Type: application/json;charset=UTF-8\n' +
        'Host: 172.26.2.22:28180\n' +
        'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36\n' +
        'x-requested-with: XMLHttpRequest',
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入header"
      }
    ],
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入header"
    }
  },
  {
    field: "body",
    label: "body:",
    component: "InputTextArea",
    defaultValue: '{\n'+
              '"category": "SERVICE",\n'+
              '"page": 1,\n'+
              '"size": 10,\n'+
              '"searchText": "",\n'+
              '"size": 10,\n'+
              '"timeRangeFilters": [],\n'+
              '"fieldFuzzySearch": [],\n'+
              '"childrenRequest": null,\n'+
              '"catalogFlag": false\n'+
             '}',
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入申请理由"
    }
  },
];
/**托管模式- 表单4*/
export const trusteeshipFormSchema4: FormSchema[] = [
  {
    field: '',
    label: '返回结果源码',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: "header2",
    label: "header:",
    component: "InputTextArea",
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    defaultValue:'Cache-Control: no-cache, no-store, max-age=0, must-revalidate\n' +
        'Content-Type: application/json\n' +
        'Date: Wed, 01 Feb 2023 08:51:06 GMT\n'+
        'Expires: Thu, 01 Feb 2023 08:51:06 GMT\n'+
        'Pragma: 0\n'+
        'Referrer-Policy: no-referrer\n' +
        'Transfer-Encoding: chunked\n' +
        'X-Content-Type-Options: nosniff\n' +
        'X-Frame-Options: DENY\n' +
        'X-XSS-Protection: 1; mode=block',
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入申请理由"
    }
  },
  {
    field: "body2",
    label: "body:",
    component: "InputTextArea",
    colProps: { "lg": 24, "md": 24 },
    rules: [
      {
        required: true,
        message: "请输入申请理由"
      }
    ],
    defaultValue:'{\n'+
              '"category": "SERVICE",\n'+
              '"page": 1,\n'+
              '"size": 10,\n'+
              '"searchText": "",\n'+
              '"size": 10,\n'+
              '"timeRangeFilters": [],\n'+
              '"fieldFuzzySearch": [],\n'+
              '"childrenRequest": null,\n'+
              '"catalogFlag": false\n'+
             '}',
    componentProps: {
      readonly: true,
      rows: 8,
      placeholder: "请输入申请理由"
    }
  },
];

/**版本对比 表单*/
export const contrastSchema: FormSchema[] = [
  {
    field: '',
    label: 'API模式',
    component: 'Input',
    defaultValue: '向导...',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardPath',
    label: '数据源',
    component: 'Input',
    defaultValue: '某能源集团人力...',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardNumber',
    label: '数据库',
    component: 'Input',
    defaultValue: 'dws',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
  {
    field: 'standardChineseName',
    label: '数据表',
    component: 'Input',
    defaultValue: 'dws_tb_employee',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
    colProps: { lg: 6, md: 6 },
  },
];
/**版本对比 列表1*/
export const contrastTableColumns1: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    width: 150
  },
  {
    title: '参数值',
    dataIndex: 'parameterValue',
    width: 150
  },
];
/**版本对比 列表2*/
export const contrastTableColumns2: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    width: 150
  },
  {
    title: '是否必填',
    dataIndex: 'required',
    width: 150
  },
  {
    title: '默认值',
    dataIndex: 'defaultValue',
    width: 150
  },
];
/**版本对比 列表3*/
export const contrastTableColumns3: BasicColumn[] = [
  {
    title: '参数code',
    dataIndex: 'parameterCode',
    width: 150
  },
  {
    title: '参数名称',
    dataIndex: 'parameterName',
    width: 150
  },
  {
    title: '注释',
    dataIndex: 'comment',
    width: 150
  },
];
/**版本列表 回滚表单*/
export const returnVersionFormSchema: FormSchema[] = [
  {
    field: 'historyVersion',
    label: '选择历史版本',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择历史版本',
      },
    ],
    componentProps: {
      options: [
        {
          label: 'V1',
          value: 'V1',
        },
        {
          label: 'V2',
          value: 'V2',
        },
        {
          label: 'V3',
          value: 'V3',
        },
      ],
      placeholder: '请选择历史版本',
    },
    colProps: { lg: 24, md: 24 },
  },
];






/**基础公共代码表单*/
export const detailSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];
/**详情页列表 表头*/
export const detailColumns: BasicColumn[] = [
  {
    title: '代码值',
    dataIndex: 'codeValue',
    width: 150
  },
  {
    title: '代码含义',
    dataIndex: 'codeMeaning',
    width: 150
  },
  {
    title: '说明',
    dataIndex: 'description',
    width: 150
  },
  {
    title: '修改人',
    dataIndex: 'updateBy',
    width: 150
  },
  {
    title: '修改时间',
    dataIndex: 'updateDate',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  }
];
/**详情页列表 表单*/
export const detailFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { span: 6 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { span: 6 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 6 },
  },
];
/**编辑公共代码 表单1*/
export const editStandardsDetailFormSchema: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准路径',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    colProps: { lg: 8, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      placeholder: '-',
    },
  },
];
/**编辑公共代码 表单2*/
export const addValueFormSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 表单3*/
export const addValueSearchSchema: FormSchema[] = [
  {
    field: 'sourceSystem',
    label: '源系统',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统',
    },
    colProps: { span: 8 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { span: 8 },
  },
];
/**编辑公共代码 表单4*/
export const editPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**详情公共代码 表单5*/
export const detailPublicCodeSchema: FormSchema[] = [
  {
    field: 'codeValue',
    label: '代码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码值',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'codeMeaning',
    label: '代码含义',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入代码含义',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'description',
    label: '说明',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入说明',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'sourceSystemCodeValue',
    label: '源系统码值',
    component: 'Input',
    required: true,
    componentProps: {
      style: {
        border: 'none',
      },
      readonly: true,
      placeholder: '请输入源系统码值',
    },
    colProps: { lg: 24, md: 24 },
  },
];
/**编辑公共代码 列表表头*/
export const addValueColumns: BasicColumn[] = [
  {
    title: '源系统',
    dataIndex: 'sourceSystem',
    width: 150
  },
  {
    title: '源系统码值',
    dataIndex: 'sourceSystemCodeValue',
    width: 150
  },
];
